@@ -18,6 +18,8 @@ RCT_EXPORT_VIEW_PROPERTY(playerWidth, NSNumber)
 RCT_EXPORT_VIEW_PROPERTY(playerHeight, NSNumber)
 RCT_EXPORT_VIEW_PROPERTY(play, NSNumber)
 RCT_EXPORT_VIEW_PROPERTY(replay, NSNumber)
+RCT_EXPORT_VIEW_PROPERTY(rotate, NSNumber)
 RCT_EXPORT_VIEW_PROPERTY(volume, NSNumber)
+RCT_EXPORT_VIEW_PROPERTY(onChange, RCTBubblingEventBlock)
 
 @end
